==> aspectran-core-5.1.0-sources.jar: com/aspectran/core/context/rule/type/ResponseType.java <==
/*
 * Copyright (c) 2008-2018 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.context.rule.type;

/**
 * Supported Response types.
 * 
 * <p>Created: 2008. 05. 02 AM 16:21:38</p>
 */
public enum ResponseType {

    TRANSFORM("transform"),
    DISPATCH("dispatch"),
    REDIRECT("redirect"),
    FORWARD("forward");

    private final String alias;

    ResponseType(String alias) {
        this.alias = alias;
    }

    @Override
    public String toString() {
        return this.alias;
    }

    /**
     * Returns a {@code ResponseType} with a value represented
     * by the specified {@code String}.
     *
     * @param alias the response type as a {@code String}
     * @return a {@code ResponseType}, may be {@code null}
     */
    public static ResponseType resolve(String alias) {
        for (ResponseType type : values()) {
            if (type.alias.equals(alias)) {
                return type;
            }
        }
        return null;
    }

}

==> aspectran-core-6.13.3-sources.jar: com/aspectran/core/context/rule/type/ResponseType.java <==
/*
 * Copyright (c) 2008-2021 The Aspectran Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.aspectran.core.context.rule.type;

/**
 * Supported response types.
 * 
 * <p>Created: 2008. 05. 02 AM 16:21:38</p>
 */
public enum ResponseType {

    TRANSFORM("transform"),
    DISPATCH("dispatch"),
    FORWARD("forward"),
    REDIRECT("redirect"),
    TEMPLATE("template");

    private final String alias;

    ResponseType(String alias) {
        this.alias = alias;
    }

    @Override
    public String toString() {
        return this.alias;
    }

    /**
     * Returns a {@code ResponseType} with a value represented
     * by the specified {@code String}.
     *
     * @param alias the response type as a {@code String}
     * @return a {@code ResponseType}, may be {@code null}
     */
    public static ResponseType resolve(String alias) {
        for (ResponseType type : values()) {
            if (type.alias.equals(alias)) {
                return type;
            }
        }
        return null;
    }

}
